# User Guide
Learn how to manage your enterprise architecture in SAP LeanIX.
This guide covers essential topics for users working with SAP LeanIX. Explore specific sections in this guide to learn how to interact with and analyze inventory data, manage your tasks, and collaborate with your team in SAP LeanIX.
If you're new to SAP LeanIX, these guides will help you get started:
  * [SAP Leanix for Enterprise Architects](https://help.sap.com/docs/leanix/ea/for-enterprise-architects?locale=en-US&state=PRODUCTION&version=CLOUD "First steps in using SAP LeanIX as an enterprise architect.")
  * [SAP LeanIX for Application and Business Owners](https://help.sap.com/docs/leanix/ea/for-application-and-business-owners?locale=en-US&state=PRODUCTION&version=CLOUD "First steps in using SAP LeanIX for application and business owners.")
